#
# spec file for package python-rope
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define upname rope
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-rope
Version:        0.17.0
Release:        bp155.2.12
Summary:        A python refactoring library
License:        LGPL-3.0-or-later
Group:          Development/Languages/Python
URL:            https://github.com/python-rope/rope
Source:         https://files.pythonhosted.org/packages/source/r/rope/rope-%{version}.tar.gz
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
Rope is a python refactoring library.

%prep
%setup -q -n rope-%{version}
%autopatch -p1

%build
export LANG=en_US.UTF-8
%python_build

%install
export LANG=en_US.UTF-8
%python_install
%{python_expand rm -rf %{buildroot}/%{$python_sitelib}/python-rope/ropetest/
%fdupes %{buildroot}/%{$python_sitelib}
}

%check
export LANG=en_US.UTF-8
%pytest

%files %{python_files}
%license COPYING
%doc README.rst
%doc docs/
%{python_sitelib}/

%changelog
* Tue May  5 2020 Matej Cepl <mcepl@suse.com>
- Update to 0.17.0:
  - Make tests compatible with Python 3.8
  - Use context manager for open()
  - Don’t use UserDict (!!!) and collections.MutableMapping.
  - assertEquals has been deprecated for long time (-> assertEqual)
  - Remove weird escpaing of 's' character, which is the syntax
    error these days.
  - Add testing for Python 3.8 as well
  - Fix pattern for matching short strings
  - Work with deprecated types and using aliased ones.
  - Don't use underscored _ast, but use ast instead
  - Direct import from collections is getting deprecated.
  - Use .is_alive method instead of a deprecated .isAlive
    in threading.Thread
  - Fix simple typo: sitaution -> situation (#287)
  - Two more assertEquals happened.
- Remove all patches, which were now included in the upstream
  tarball:
  - Python38-compatibility.patch
  - assertEquals.patch
  - isAlive_failed_test.patch
  - obsolete_escape_strings.patch
* Mon Mar  9 2020 Matej Cepl <mcepl@suse.com>
- Add assertEquals.patch, obsolete_escape_strings.patch, and
  Python38-compatibility.patch to deal with various deprecated
  warnings.
- Switch off three tests to make the test suite pass under Python
  3.8.
* Thu Mar  5 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.16.0
  * new minor relase with bugfixes.
* Tue Jan 14 2020 Matej Cepl <mcepl@suse.com>
- Add isAlive_failed_test.patch as a fix for gh#python-rope/rope#283
* Thu Jan  2 2020 Tomáš Chvátal <tchvatal@suse.com>
- Run the pytest call only once
* Fri Mar 22 2019 Matej Cepl <mcepl@suse.com>
- Upgrade to 0.14.0:
  - relicensing to LGPLv3+
  - bugfixes
* Thu Mar  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix expansion of test removal
* Mon Feb 11 2019 Matej Cepl <mcepl@suse.com>
- Upgrade to 0.12.0:
  * gh#python-rope/rope#218: support for all of the new
    async-related nodes.
  * gh#python-rope/rope#259: fix installation issues on Windows
* Wed Jan 16 2019 mcepl@suse.com
- Workaround gh#python-rope/rope#247 (some tests fail on Python 3.7)
* Wed Aug 29 2018 tchvatal@suse.com
- Fix buildrequires to not require devel
- Run tests without conditional
* Thu Aug  9 2018 mcepl@suse.com
- update to 0.11.0
  + Upstream provides no changelog
- Remove patch CVE-2014-3539-disable-doa.patch (included upstream)
* Mon Aug 28 2017 toddrme2178@gmail.com
- update to 0.10.7
  + Upstream provides no changelog
- Add tag for CVE-2014-3539-disable-doa.patch
* Fri Jul 21 2017 sebix+novell.com@sebix.at
- convert to singlespec
- update to 0.10.5
* Mon Jul 13 2015 toddrme2178@gmail.com
- Fix building on SLES 11
* Wed Feb 18 2015 jmatejek@suse.com
- update to version 0.10.2
  * new maintainer revives project
  * accumulated bugfixes
  * better test coverage and all tests pass
- disable dynamic object analysis by default, as it is a security risk
  (CVE-2014-3539-disable-doa.patch, CVE-2014-3539, boo#916890)
* Wed Jun  6 2012 saschpe@suse.de
- Update to version 0.9.4:
  + Upstream provides no changelog
* Tue Jan 31 2012 saschpe@suse.de
- Spec file cleanup
* Mon Dec  5 2011 toddrme2178@gmail.com
- Cleaned up spec file formatting
* Tue Jan 25 2011 saschpe@suse.de
- Update to version 0.9.3
- Added COPYING to documentation
- Recompressed tarbal with bzip2
* Wed Aug  5 2009 hpj@urpla.net
- Initial creation of package python-rope-0.9.2
